---
title: <span class="badge object-type-scalar"></span> Mebibytes
---
# <span class="badge object-type-scalar"></span> Mebibytes

Data: mebibytes

## Definition

```python
# Data: mebibytes
Mebibytes: typing.Literal["mbytes"] = "mbytes"
```
